Struct chiro::structures::TypeKey
source · [−]pub struct TypeKey {
pub code: TypeKeyCode,
pub shift: bool,
pub control: bool,
}Fields
code: TypeKeyCodeshift: boolcontrol: boolTrait Implementations
sourceimpl Ord for TypeKey
impl Ord for TypeKey
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<TypeKey> for TypeKey
impl PartialEq<TypeKey> for TypeKey
sourceimpl PartialOrd<TypeKey> for TypeKey
impl PartialOrd<TypeKey> for TypeKey
sourcefn partial_cmp(&self, other: &TypeKey) -> Option<Ordering>
fn partial_cmp(&self, other: &TypeKey) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for TypeKey
impl Eq for TypeKey
impl StructuralEq for TypeKey
impl StructuralPartialEq for TypeKey